@@ -131,7 +131,7 @@ or add C<RT::Extension::JSGantt> to your existing C<@Plugins> line.
 
 package RT::Extension::JSGantt;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use warnings;
 use strict;
@@ -215,7 +215,7 @@ sub TicketsInfo {
     if ( $options{ColorSchemeByOwner} ) {
         my @owner_names = uniq map { $_->OwnerObj->Name } @{ $args{Tickets} };
         @color_map{@owner_names} =
-          (@colors) x ( int @colors / @owner_names + 1 );
+          (@colors) x ( ( @owner_names ? int @colors / @owner_names : 0 ) + 1 );
         if (   ref $options{ColorSchemeByOwner}
             && ref $options{ColorSchemeByOwner} eq 'HASH' )
         {
